@@ -48,13 +48,14 @@ class CycloneDx(ScanossBase):
         """
         Parse the given input (raw/plain) JSON string and return CycloneDX summary
         :param data: json - JSON object
-        :return: CycloneDX dictionary
+        :return: CycloneDX dictionary, and vulnerability dictionary
         """
         if not data:
             self.print_stderr('ERROR: No JSON data provided to parse.')
-            return None
+            return None, None
         self.print_debug(f'Processing raw results into CycloneDX format...')
         cdx = {}
+        vdx = {}
         for f in data:
             file_details = data.get(f)
             # print(f'File: {f}: {file_details}')
@@ -101,10 +102,36 @@ class CycloneDx(ScanossBase):
                     if not purl:
                         self.print_stderr(f'Warning: No PURL found for {f}: {file_details}')
                         continue
+                    fd = {}
+                    vulnerabilities = d.get("vulnerabilities")
+                    if vulnerabilities:
+                        for vuln in vulnerabilities:
+                            vuln_id = vuln.get("ID")
+                            if vuln_id == '':
+                                vuln_id = vuln.get("id")
+                            if not vuln_id or vuln_id == '':  # Skip empty ids
+                                continue
+                            vuln_cve = vuln.get("CVE", '')
+                            if vuln_cve == '':
+                                vuln_cve = vuln.get("cve", '')
+                            if vuln_id.upper().startswith("CPE:"):
+                                fd['cpe'] = vuln_id                 # Save the component CPE if we have one
+                                if vuln_cve != '':
+                                    vuln_id = vuln_cve
+                            vd = vdx.get(vuln_id)  # Check if we've already encountered this vulnerability
+                            if not vd:
+                                vuln_source = vuln.get('source', '').lower()
+                                vd = {'cve': vuln_cve,
+                                      'source': 'NVD' if vuln_source == 'nvd' else 'GitHub Advisories',
+                                      'url': f'https://nvd.nist.gov/vuln/detail/{vuln_cve}' if vuln_source == 'nvd' else f'https://github.com/advisories/{vuln_id}',
+                                      'severity': self._sev_lookup(vuln.get('severity', 'unknown').lower()),
+                                      'affects': set()
+                                      }
+                            vd.get('affects').add(purl)
+                            vdx[vuln_id] = vd
                     if cdx.get(purl):
                         self.print_debug(f'Component {purl} already stored: {cdx.get(purl)}')
                         continue
-                    fd = {}
                     for field in ['id', 'vendor', 'component', 'version', 'latest']:
                         fd[field] = d.get(field)
                     licenses = d.get('licenses')
@@ -113,7 +140,9 @@ class CycloneDx(ScanossBase):
                         fdl.append({'id': lic.get("name")})
                     fd['licenses'] = fdl
                     cdx[purl] = fd
-        return cdx
+        # self.print_stderr(f'VD: {vdx}')
+        # self.print_stderr(f'CDX: {cdx}')
+        return cdx, vdx
 
     def produce_from_file(self, json_file: str, output_file: str = None) -> bool:
         """
@@ -139,7 +168,7 @@ class CycloneDx(ScanossBase):
         :param output_file: Output file (optional)
         :return: True if successful, False otherwise
         """
-        cdx = self.parse(data)
+        cdx, vdx = self.parse(data)
         if not cdx:
             self.print_stderr('ERROR: No CycloneDX data returned for the JSON string provided.')
             return False
@@ -154,7 +183,8 @@ class CycloneDx(ScanossBase):
             'specVersion': '1.4',
             'serialNumber': f'urn:uuid:{uuid.uuid4()}',
             'version': 1,
-            'components': []
+            'components': [],
+            'vulnerabilities': []
         }
         for purl in cdx:
             comp = cdx.get(purl)
@@ -172,16 +202,38 @@ class CycloneDx(ScanossBase):
                         lic_text.append({'license': {'name': lc_id}})  # Not an SPDX license, so store it by name
                     else:
                         lic_text.append({'license': {'id': spdx_id}})
-            m_type = 'library'
-            data['components'].append({
-                'type': m_type,
+            c_data = {
+                'type': 'library',
                 'name': comp.get('component'),
                 'publisher': comp.get('vendor', ''),
                 'version': comp.get('version'),
                 'purl': purl,
+                'bom-ref': purl,
                 'licenses': lic_text
-            })
+            }
+            cpe = comp.get('cpe', '')
+            if cpe and cpe != '':
+                c_data['cpe'] = cpe
+            data['components'].append(c_data)
         # End for loop
+        if vdx:
+            for vuln_id in vdx:
+                vulns = vdx.get(vuln_id)
+                if not vulns:
+                    continue
+                v_source = vulns.get('source')
+                affects = []
+                for purl in vulns.get('affects'):
+                    affects.append({'ref': purl})
+                vd = {
+                    'id': vuln_id,
+                    'source': {'name': v_source, 'url': vulns.get('url')},
+                    'ratings': [{'severity': vulns.get('severity', 'unknown')}],
+                    'affects': affects
+                }
+                data['vulnerabilities'].append(vd)
+            # End for loop
+
         file = sys.stdout
         if not output_file and self.output_file:
             output_file = self.output_file
@@ -209,6 +261,24 @@ class CycloneDx(ScanossBase):
             self.print_stderr(f'ERROR: Problem parsing input JSON: {e}')
             return False
         return self.produce_from_json(data, output_file)
+
+    @staticmethod
+    def _sev_lookup(value: str):
+        """
+        Lookup the given severity and return a CycloneDX valid version
+        :param value: severity to lookup
+        :return: CycloneDX severity
+        """
+        return {
+            'critical': 'critical',
+            'high': 'high',
+            'medium': 'medium',
+            'moderate': 'medium',
+            'low': 'low',
+            'info': 'info',
+            'none': 'none',
+            'unknown': 'unknown'
+            }.get(value, 'unknown')
 #
 # End of CycloneDX Class
 #
